@@ -62,7 +62,7 @@ Or you can get the bytes (new in `1.11.0`):
 '''
 import re
 from base64 import b64decode
-import imghdr
+from filetype import guess_extension
 
 __all__ = ('Image', 'ImageLoader', 'ImageData')
 
@@ -188,7 +188,7 @@ class ImageData(object):
         '''
         if level == 0:
             return (self.width, self.height, self.data, self.rowlength)
-        assert(level < len(self.mipmaps))
+        assert level < len(self.mipmaps)
         return self.mipmaps[level]
 
     def iterate_mipmaps(self):
@@ -424,7 +424,7 @@ class ImageLoader(object):
                 afn += '.atlas'
             afn = resource_find(afn)
             if not afn:
-                raise Exception('Unable to found %r atlas' % afn)
+                raise Exception('Unable to find %r atlas' % afn)
             atlas = Atlas(afn)
             Cache.append('kv.atlas', rfn, atlas)
             # first time, fill our texture cache.
@@ -443,6 +443,9 @@ class ImageLoader(object):
 
         filename = resource_find(filename)
 
+        # Get actual image format instead of extension if possible
+        ext = guess_extension(filename) or ext
+
         # special case. When we are trying to load a "zip" file with image, we
         # will use the special zip_loader in ImageLoader. This might return a
         # sequence of images contained in the zip.
@@ -450,8 +453,6 @@ class ImageLoader(object):
             return ImageLoader.zip_loader(filename)
         else:
             im = None
-            # Get actual image format instead of extension if possible
-            ext = imghdr.what(filename) or ext
             for loader in ImageLoader.loaders:
                 if ext not in loader.extensions():
                     continue
